==> ansible-lint-6.8.2.tar.gz: ansible-lint-6.8.2/README.md <==
[![PyPI version](https://img.shields.io/pypi/v/ansible-lint.svg)](https://pypi.org/project/ansible-lint)
[![Ansible-lint rules explanation](https://img.shields.io/badge/Ansible--lint-rules%20table-blue.svg)](https://ansible-lint.readthedocs.io/default_rules)
[![Discussions](https://img.shields.io/badge/Discussions-gray.svg)](https://github.com/ansible/ansible-lint/discussions)
[![GitHub Actions CI/CD](https://github.com/ansible-community/ansible-lint/workflows/gh/badge.svg)](https://github.com/ansible/ansible-lint/actions?query=workflow%3Agh+branch%3Amain+event%3Apush)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/ansible-community/ansible-lint.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/ansible-community/ansible-lint/context:python)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

# Ansible-lint

`ansible-lint` checks playbooks for practices and behavior that could
potentially be improved. As a community backed project ansible-lint supports
only the last two major versions of Ansible.

[Visit the Ansible Lint docs site](https://ansible-lint.readthedocs.io/)

# Contributing

Please read [Contribution guidelines] if you wish to contribute.

# Licensing

The ansible-lint project is distributed as [GPLv3] due to use of [GPLv3] runtime
dependencies, like `ansible` and `yamllint`.

For historical reasons, its own code-base remains licensed under a more
liberal [MIT] license and any contributions made are accepted as being made
under original [MIT] license.

# Authors

ansible-lint was created by [Will Thames] and is now maintained as part of the
[Ansible] by [Red Hat] project.

[ansible]: https://ansible.com
[contribution guidelines]: https://ansible-lint.readthedocs.io/contributing
[gplv3]: https://github.com/ansible-community/ansible-lint/blob/main/COPYING
[mit]: https://github.com/ansible-community/ansible-lint/blob/main/docs/licenses/LICENSE.mit.txt
[red hat]: https://redhat.com
[will thames]: https://github.com/willthames

==> ansible-lint-6.10.0a0.tar.gz: ansible-lint-6.10.0a0/README.md <==
[![PyPI version](https://img.shields.io/pypi/v/ansible-lint.svg)](https://pypi.org/project/ansible-lint)
[![Ansible-lint rules explanation](https://img.shields.io/badge/Ansible--lint-rules-blue.svg)](https://ansible-lint.readthedocs.io/rules/)
[![Discussions](https://img.shields.io/badge/Discussions-gray.svg)](https://github.com/ansible/ansible-lint/discussions)
[![GitHub Actions CI/CD](https://github.com/ansible/ansible-lint/workflows/gh/badge.svg)](https://github.com/ansible/ansible-lint/actions?query=workflow%3Agh+branch%3Amain+event%3Apush)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/ansible/ansible-lint.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/ansible-community/ansible-lint/context:python)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

# Ansible-lint

`ansible-lint` checks playbooks for practices and behavior that could
potentially be improved. As a community backed project ansible-lint supports
only the last two major versions of Ansible.

[Visit the Ansible Lint docs site](https://ansible-lint.readthedocs.io/)

# Contributing

Please read [Contribution guidelines] if you wish to contribute.

# Licensing

The ansible-lint project is distributed as [GPLv3] due to use of [GPLv3] runtime
dependencies, like `ansible` and `yamllint`.

For historical reasons, its own code-base remains licensed under a more
liberal [MIT] license and any contributions made are accepted as being made
under original [MIT] license.

# Authors

ansible-lint was created by [Will Thames] and is now maintained as part of the
[Ansible] by [Red Hat] project.

[ansible]: https://ansible.com
[contribution guidelines]: https://ansible-lint.readthedocs.io/contributing
[gplv3]: https://github.com/ansible/ansible-lint/blob/main/COPYING
[mit]: https://github.com/ansible/ansible-lint/blob/main/docs/licenses/LICENSE.mit.txt
[red hat]: https://redhat.com
[will thames]: https://github.com/willthames
